@@ -5,13 +5,19 @@ cp("./docs/Project.toml", "./docs/src/assets/Project.toml", force = true)
 
 include("pages.jl")
 
-makedocs(sitename = "LabelledArrays.jl",
+makedocs(
+    sitename = "LabelledArrays.jl",
     authors = "Chris Rackauckas",
     modules = [LabelledArrays],
     clean = true, doctest = false, linkcheck = true,
-    format = Documenter.HTML(assets = ["assets/favicon.ico"],
-        canonical = "https://docs.sciml.ai/LabelledArrays/stable/"),
-    pages = pages)
+    format = Documenter.HTML(
+        assets = ["assets/favicon.ico"],
+        canonical = "https://docs.sciml.ai/LabelledArrays/stable/"
+    ),
+    pages = pages
+)
 
-deploydocs(repo = "github.com/SciML/LabelledArrays.jl.git";
-    push_preview = true)
+deploydocs(
+    repo = "github.com/SciML/LabelledArrays.jl.git";
+    push_preview = true
+)
